summaryrefslogtreecommitdiff
path: root/sys/arch/wgrisc/stand/boot/conf.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/arch/wgrisc/stand/boot/conf.c')
-rw-r--r--sys/arch/wgrisc/stand/boot/conf.c37
1 files changed, 18 insertions, 19 deletions
diff --git a/sys/arch/wgrisc/stand/boot/conf.c b/sys/arch/wgrisc/stand/boot/conf.c
index fa2b4cb730c..3c991b8edbe 100644
--- a/sys/arch/wgrisc/stand/boot/conf.c
+++ b/sys/arch/wgrisc/stand/boot/conf.c
@@ -1,12 +1,8 @@
-/* $NetBSD: conf.c,v 1.5 1995/01/18 06:53:39 mellon Exp $ */
+/* $OpenBSD: conf.c,v 1.2 1997/07/21 06:58:12 pefo Exp $ */
/*
- * Copyright (c) 1992, 1993
- * The Regents of the University of California. All rights reserved.
- *
- * This code is derived from software contributed to Berkeley by
- * Ralph Campbell.
- *
+ * Copyright (c) 1997 Per Fogelstrom
+ *
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
@@ -17,17 +13,16 @@
* documentation and/or other materials provided with the distribution.
* 3. All advertising materials mentioning features or use of this software
* must display the following acknowledgement:
* This product includes software developed by the University of
* California, Berkeley and its contributors.
* 4. Neither the name of the University nor the names of its contributors
* may be used to endorse or promote products derived from this software
* without specific prior written permission.
*
- * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
+ * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
+ * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
* DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
* OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
* HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
@@ -35,9 +30,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * @(#)conf.c 8.1 (Berkeley) 6/10/93
*/
-
#include <stand.h>
int errno;
@@ -50,10 +43,16 @@ int sdstrategy __P((void *, int, daddr_t, size_t, void *, size_t *));
int sdopen __P((struct open_file *, ...));
int sdclose __P((struct open_file *));
+int flstrategy __P((void *, int, daddr_t, size_t, void *, size_t *));
+int flopen __P((struct open_file *, ...));
+int flclose __P((struct open_file *));
+
#define sdioctl noioctl
+#define flioctl noioctl
struct devsw devsw[] = {
{ "sd", sdstrategy, sdopen, sdclose, sdioctl }, /*0*/
+ { "fl", flstrategy, flopen, flclose, flioctl }, /*1*/
};
int ndevs = (sizeof(devsw)/sizeof(devsw[0]));
@@ -17,17 +13,16 @@
* 3. All advertising materials mentioning features or use of this software
* must display the following acknowledgement:
- * This product includes software developed by the University of
- * California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
- * may be used to endorse or promote products derived from this software
- * without specific prior written permission.
+ * This product includes software developed under OpenBSD by
+ * Per Fogelstrom.
+ * 4. The name of the author may not be used to endorse or promote products
+ * derived from this software without specific prior written permission.
*